/*
 *  Éditez ce fichier et copiez-le en le renommant userContent.css
 *  dans le répertoire Chrome de votre profil
 */

/*
 *  Ce fichier peut être utilisé pour appliquer des règles de style à 
 *  toutes les pages Web que vous visiterez.
 *  Pensez à ajouter "! important" à vos règles de style pour qu'elles
 *  aient priorité sur les réglages de l'auteur de la page.
 */

/*
 *  exemple: empêcher le clignotement d'éléments ("blink")
 *
 *  blink { text-decoration: none ! important; }
 *
 */

/*
 *  exemple: forcer tous les tableaux à s'afficher avec une bordure de 2 pixels
 *
 *  table { border: 2px solid ! important; }
 *
 */

/*
 *  exemple: désactiver l'élément "marquee"
 *
 *  marquee { -moz-binding: none ! important; }
 *
 */
 
/* 
 *  Pour plus d'exemples, voir: http://www.mozilla.org/unix/customizing.html
 */

